#
# spec file for package python-ijson
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ijson
Version:        3.0
Release:        bp155.2.12
Summary:        Iterative JSON parser with a standard Python iterator interface
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ICRAR/ijson
Source:         https://files.pythonhosted.org/packages/source/i/ijson/ijson-%{version}.tar.gz
# https://github.com/ICRAR/ijson/pull/26
Source1:        https://raw.githubusercontent.com/ICRAR/ijson/master/tests_asyncio.py
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-asyncio
BuildRequires:  pkgconfig(yajl)
%python_subpackages

%description
Iterative JSON parser with a standard Python iterator interface.

%prep
%setup -q -n ijson-%{version}
cp %{SOURCE1} .

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%python_exec tests.py

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitearch}/*

%changelog
* Thu Apr  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.0
  * Exposing backend's name under ``<backend>.backend``,
  and default backend's name under ``ijson.backend``.
  * Exposing ``ijson.sendable_list`` to users in case it comes in handy.
  * Improved the protocol for user-facing coroutines,
  where instead of having to send a final, empty bytes string
  to finish the parsing process
  users can simply call ``.close()`` on the coroutine.
  * Including C code in coverage measurements,
  and increased overall code coverage up to 99%%.
  * Full re-design of ijson.
  * Initial support for ``asyncio`` in python 3.5+.
  * Exposure of underlying infrastructure implementing the push model.
  * C extension broken down into separate source files
  for easier understanding and maintenance.
  * Fixed a deprecation warning in the C backend
  present in python 3.8 when parsing Decimal values.
  * New `kvitems` method in all backends.
  Like `items`, it takes a prefix,
  and iterates over the key/value pairs of matching objects
  (instead of iterating over objects themselves, like in `items`).
  * When using python 2, all backends now return
  `map_key` values as `unicode` objects, not `str`.
  * Including more files in source distributions (#14).
  * Adjusting python backend to avoid reading off the input stream
  too eagerly (#15).
* Fri Oct 18 2019 John Vandenberg <jayvdb@gmail.com>
- Use libyajl
- Update URL to new maintainer https://github.com/ICRAR/ijson
- Update to v2.5.1
* Wed Mar 27 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.3
